@@ -4,8 +4,7 @@
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef ARTICLEVIEWERWEBENGINE_H
-#define ARTICLEVIEWERWEBENGINE_H
+#pragma once
 
 #include <MessageViewer/ViewerPluginInterface>
 #include <WebEngineViewer/CheckPhishingUrlJob>
@@ -19,6 +18,8 @@ namespace WebEngineViewer
 class WebHitTestResult;
 class WebEngineAccessKey;
 class InterceptorManager;
+class LoadExternalReferencesUrlInterceptor;
+class BlockExternalResourcesUrlInterceptor;
 }
 namespace MessageViewer
 {
@@ -63,6 +64,8 @@ public:
 
     void execPrintPreviewPage(QPrinter *printer, int timeout);
 
+    virtual void updateSecurity();
+
 protected:
     QUrl mCurrentUrl;
     KActionCollection *const mActionCollection;
@@ -94,6 +97,7 @@ Q_SIGNALS:
     void findTextInHtml();
     void textToSpeech();
     void webPageMutedOrAudibleChanged(bool isAudioMuted, bool wasRecentlyAudible);
+    void trackingFound(const WebEngineViewer::BlockTrackingUrlInterceptor::TrackerBlackList &);
 
 protected:
     void resizeEvent(QResizeEvent *e) override;
@@ -124,6 +128,8 @@ protected:
     ArticleViewerWebEnginePage *mPageEngine = nullptr;
     QList<QAction *> viewerPluginActionList(MessageViewer::ViewerPluginInterface::SpecificFeatureTypes features);
     WebEngineViewer::InterceptorManager *mNetworkAccessManager = nullptr;
+    WebEngineViewer::LoadExternalReferencesUrlInterceptor *mExternalReference = nullptr;
+    WebEngineViewer::BlockExternalResourcesUrlInterceptor *mBlockExternalReference = nullptr;
 
 private:
     void openSafeUrl(const QUrl &url);
@@ -134,4 +140,3 @@ private:
 };
 }
 
-#endif // ARTICLEVIEWERWEBENGINE_H
