@@ -5,8 +5,7 @@
 
     SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
-#ifndef AKREGATOR_BACKEND_FEEDSTORAGEDUMMYIMPL_H
-#define AKREGATOR_BACKEND_FEEDSTORAGEDUMMYIMPL_H
+#pragma once
 
 #include "feedstorage.h"
 namespace Akregator
@@ -77,4 +76,3 @@ private:
 } // namespace Backend
 } // namespace Akregator
 
-#endif // AKREGATOR_FEEDSTORAGEDUMMYIMPL_H
